@@ -168,6 +168,22 @@ class AnnotatedText(Iaswn):
         self.annotatedstrings = SemiSortedTextRefsDict(
             textrefclass=self.options["AnnotatedText:TextRef class(type)"])
 
+    def __eq__(self,
+               other):
+        """
+            AnnotatedText.__eq__()
+
+            This method is primarily used for testing.
+            ___________________________________________________________________
+
+            ARGUMENT: <other>, an AnnotatedText object
+
+            RETURNED VALUE: True if <self> and <other> are equal, False otherwise.
+        """
+        return self.errors == other.errors and \
+               self.options == other.options and \
+               self.annotatedstrings == other.annotatedstrings
+
     def _get_textref_object(self,
                             source_string: str = None):
         """
